==> haskell-jose-0.10-144-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-jose.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 jose
version:              0.10
visibility:           public
id:                   jose-0.10-56Gdts29PQAEPZI6TbqUnR
key:                  jose-0.10-56Gdts29PQAEPZI6TbqUnR
license:              Apache-2.0
copyright:            Copyright (C) 2013-2021  Fraser Tweedale
maintainer:           frase@frase.id.au
author:               Fraser Tweedale
homepage:             https://github.com/frasertweedale/hs-jose
synopsis:
    JSON Object Signing and Encryption (JOSE) and JSON Web Token (JWT) library

description:

    Implementation of JSON Object Signing and Encryption
    (JOSE) and JSON Web Token (JWT; RFC 7519).

    The JSON Web Signature (JWS; RFC 7515) implementation is complete.

    EdDSA signatures (RFC 8037) and secp256k1 (RFC 8812) are supported.

    JWK Thumbprint (RFC 7638) is supported.

    JSON Web Encryption (JWE; RFC 7516) is not yet implemented.

    The __ECDSA implementation is vulnerable to timing attacks__ and
    should only be used for verification.

category:             Cryptography
abi:                  3a6dc5ea5cd5f5721398bf6cbae7863e
exposed:              True
exposed-modules:
    Crypto.JOSE Crypto.JOSE.AESKW Crypto.JOSE.Compact Crypto.JOSE.Error
    Crypto.JOSE.Header Crypto.JOSE.JWA.JWE Crypto.JOSE.JWA.JWE.Alg
    Crypto.JOSE.JWA.JWK Crypto.JOSE.JWA.JWS Crypto.JOSE.JWE
    Crypto.JOSE.JWK Crypto.JOSE.JWK.Store Crypto.JOSE.JWS
    Crypto.JOSE.Types Crypto.JWT

hidden-modules:
    Crypto.JOSE.TH Crypto.JOSE.Types.Internal Crypto.JOSE.Types.URI

import-dirs:          /usr/lib/ghc-9.4.8/site-local/jose-0.10
library-dirs:         /usr/lib/ghc-9.4.8/site-local/jose-0.10
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/jose-0.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-jose
hs-libraries:         HSjose-0.10-56Gdts29PQAEPZI6TbqUnR
depends:
    aeson-2.1.2.1-Ex7WnNUT1auEGSF1Md5zyM base-4.17.2.1
    base64-bytestring-1.2.1.0-Ho7haZ0JPmRAFS27fbQFVQ
    bytestring-0.11.5.3 concise-0.1.0.1-2slBzqD9Bumld7qwGPF8a
    containers-0.6.7 cryptonite-0.30-7zAI4Osc5DqDSnQ0JPp2cc
    lens-5.2.3-3fSsMRucgnZ99PomxyWs7a
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    monad-time-0.4.0.0-LPoHPY62S3DIdducY8Hb6X mtl-2.2.2
    network-uri-2.6.4.2-BIKL9TLrelsK4TaGh1MfNw
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    x509-1.7.7-EMJygAbklYF9Po2fzdgsGt

haddock-interfaces:   /usr/share/doc/haskell-jose/html/jose.haddock
haddock-html:         /usr/share/doc/haskell-jose/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-jose-0.10-145-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-jose.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 jose
version:              0.10
visibility:           public
id:                   jose-0.10-E4UOVvZWQdiCHrlJQhq46d
key:                  jose-0.10-E4UOVvZWQdiCHrlJQhq46d
license:              Apache-2.0
copyright:            Copyright (C) 2013-2021  Fraser Tweedale
maintainer:           frase@frase.id.au
author:               Fraser Tweedale
homepage:             https://github.com/frasertweedale/hs-jose
synopsis:
    JSON Object Signing and Encryption (JOSE) and JSON Web Token (JWT) library

description:

    Implementation of JSON Object Signing and Encryption
    (JOSE) and JSON Web Token (JWT; RFC 7519).

    The JSON Web Signature (JWS; RFC 7515) implementation is complete.

    EdDSA signatures (RFC 8037) and secp256k1 (RFC 8812) are supported.

    JWK Thumbprint (RFC 7638) is supported.

    JSON Web Encryption (JWE; RFC 7516) is not yet implemented.

    The __ECDSA implementation is vulnerable to timing attacks__ and
    should only be used for verification.

category:             Cryptography
abi:                  7a9e6753565259b3ee8423f5d602872f
exposed:              True
exposed-modules:
    Crypto.JOSE Crypto.JOSE.AESKW Crypto.JOSE.Compact Crypto.JOSE.Error
    Crypto.JOSE.Header Crypto.JOSE.JWA.JWE Crypto.JOSE.JWA.JWE.Alg
    Crypto.JOSE.JWA.JWK Crypto.JOSE.JWA.JWS Crypto.JOSE.JWE
    Crypto.JOSE.JWK Crypto.JOSE.JWK.Store Crypto.JOSE.JWS
    Crypto.JOSE.Types Crypto.JWT

hidden-modules:
    Crypto.JOSE.TH Crypto.JOSE.Types.Internal Crypto.JOSE.Types.URI

import-dirs:          /usr/lib/ghc-9.4.8/site-local/jose-0.10
library-dirs:         /usr/lib/ghc-9.4.8/site-local/jose-0.10
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/jose-0.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-jose
hs-libraries:         HSjose-0.10-E4UOVvZWQdiCHrlJQhq46d
depends:
    aeson-2.1.2.1-4xKrNuS491zGhSp7DRfhkt base-4.17.2.1
    base64-bytestring-1.2.1.0-7Nrkh6WJI5e9Cz7LMEn1Am
    bytestring-0.11.5.3 concise-0.1.0.1-7fWEt4TXXwVJWMe2wU0viP
    containers-0.6.7 cryptonite-0.30-JHDjm8e86LJ9FyfS9N6hxO
    lens-5.2.3-KfchkrYqe7G7U6wvL6YyJ5
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    monad-time-0.4.0.0-LPoHPY62S3DIdducY8Hb6X mtl-2.2.2
    network-uri-2.6.4.2-LasBgzbxOez8glrUZNmNYq
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    x509-1.7.7-8VtkzoauHpDJh1scXDAMMe

haddock-interfaces:   /usr/share/doc/haskell-jose/html/jose.haddock
haddock-html:         /usr/share/doc/haskell-jose/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
